netatmo-api-python
==================

Simple API to access Netatmo weather station data from any python script
For more detailed information see http://dev.netatmo.com

I have no relation with the netatmo company, I wrote this because I needed it myself,
and published it to save time to anyone who would have same needs.

### Install ###

To install lnetatmo simply run:

    python setup.py install

Depending on your permissions you might be required to use sudo.
Once installed you can simple add lnetatmo to your python scripts by including:

    import lnetatmo

### Note ###

this release is an interim release waiting for Netatmo dashboard finalization. As any work in progress, it can stop to work at any time if serious changes occurs.
